import React, { useState } from 'react';
import styled from "styled-components";
import Loading from '../../util/Loading';
import useGameInfo from '../../../hooks/useGameInfo';
import ClickToCopy from '../../util/ClickToCopy';
import SummaryMap from './SummaryMap';
import LinkedGame from './LinkedGame';
import RoundSelect from './RoundSelect';
import ScoreBoard from './ScoreBoard';

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;
  height: 100%;
`

const Label = styled.span`
  padding: 0.2em;
  margin-bottom: 0.5em;
`

export default () => {
  // poll the game state
  const { gameId, players, coords, rounds, linkedGame }  = useGameInfo();

  // set up round number selection
  const [roundNum, setRoundNum] = useState("0");
  const roundActive = rounds > 1 ? roundNum : "1";

  // set up the summary URL
  const summaryURL = new URL(window.location.href);
  summaryURL.searchParams.append("summary", gameId);

  if (!players) {
    return <Loading/>
  }

  return (
    <Container>
      { rounds > 1 ? <RoundSelect {...{ rounds, roundNum, setRoundNum }} /> : null }
      <SummaryMap {...{ players, coords, roundActive }}/>
      <ScoreBoard {...{ players }} />
      <LinkedGame {...{ linkedGame, gameId }} />
      <Label><ClickToCopy text={summaryURL.href}>Click here to copy a link to this summary!</ClickToCopy></Label>
    </Container>
  );
}
