import React, { useRef, useEffect } from "react";
import styled from "styled-components";
import useMap from '../../../hooks/useMap';
import useMarkersFromGuesses from '../../../hooks/useMarkersFromGuesses';

const MapDiv = styled.div`
  position: absolute;
  height: 30%;
  width: 90%;
`;

const MapContainer = styled.div`
  height: 100%;
  display: flex;
  justify-content: center;
`;

export default ({ players, coords, roundActive }) => {
  // create the map
  const mapDivRef = useRef(null);
  const mapRef = useMap(mapDivRef, 0, 0, 1);

  // get the target point
  const targetPoint = coords?.[roundActive] ?? null;

  // put the markers on the map
  useMarkersFromGuesses(mapRef, players, roundActive, targetPoint);

  // scroll the map to the target point
  useEffect(() => {
    if (targetPoint && mapRef.current) {
      mapRef.current.panTo(targetPoint);
    }
  }, [mapRef, targetPoint]);

  return (
    <MapContainer>
      <MapDiv ref={mapDivRef}/>
    </MapContainer>
  );
}
